# friendly-traceback
Aimed at Python beginners: replacing standard traceback by something easier to understand, translatable into various languages.

[See the documentation here](https://aroberge.github.io/friendly-traceback-docs/docs/html/)

Friendly-traceback uses Black.
![Black logo](https://img.shields.io/badge/code%20style-black-000000.svg)

## State of this project

Friendly-traceback is alpha. The current focus is on quickly increasing
the number of exceptions covered.  We strive to test the code as new additions
are made: everything included should work.  However, the code itself
could probably be refactored and could definitely be better documented.

## Code of Conduct

We completely support the
[Python Community Code of Conduct](https://www.python.org/psf/codeofconduct/).
Contributors to this project, including those filing or commenting on an issue,
are expected to do the same.


## Note about the documentation

See [Issue #11](https://github.com/aroberge/friendly-traceback/issues/11).
